# Unofficial pip distribution of images

## Disclaimer

- This repository is not affiliated with the official `images` project. It is intended to provide a convenient way to install the library for educational purposes. Please refer to the official website for the latest information and documentation: [images](https://lambertk.academic.wlu.edu/publications/python-programming/fundamentals-of-python/the-images-api/).
- This project is provided for educational purposes only. The authors of this repository are not responsible for any issues arising from its use.

## Description
> This module, written by Kenneth Lambert, supports simple image processing.  
The Image class represents either an image loaded from a GIF file or a blank image.

See [original project](https://lambertk.academic.wlu.edu/publications/python-programming/fundamentals-of-python/the-images-api/) for details.

## Installation

```bash
pip install images-py
```

## Feedback:

For feedback on the original `images` library, please contact Ken Lambert at lambertk@wlu.edu.

## License:

The license for this distribution is the same as the original `images` library (the GPL license). Please consult the official documentation for details.

